@@ -52,7 +52,7 @@
 #' 
 #' @importFrom doFuture registerDoFuture
 #' @importFrom doRNG %dorng%
-#' @importFrom foreach %do% %dopar% foreach
+#' @importFrom foreach %do% %dopar% foreach setDoPar
 #' @importFrom future multisession plan
 #' @importFrom lifecycle badge deprecate_warn deprecated is_present
 #' @importFrom sparr risk
@@ -132,8 +132,9 @@ jitter_power <- function(obs_data,
   
   ## Set function used in foreach
   if (parallel == TRUE){
-    doFuture::registerDoFuture()
-    future::plan(multisession, workers = n_core)
+    oldplan <- doFuture::registerDoFuture()
+    on.exit(with(oldplan, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
+    future::plan(future::multisession, workers = n_core)
     `%fun%` <- doRNG::`%dorng%`
   } else { `%fun%` <- foreach::`%do%` }
   
